@@ -287,7 +287,7 @@ class YandexParser(object):
     def is_yandex(cls, content):
         return '<a class="logo__link" href="//www.yandex.' in content \
             or u'<title>Яндекс' in content \
-            or 'href="https://www.yandex.ru" title="Яндекс"' in content \
+            or u'href="https://www.yandex.ru" title="Яндекс"' in content \
             or '<a class="logo logo_type_link' in content
 
     def get_clean_html(self):
@@ -727,7 +727,6 @@ class YandexParser(object):
         span_text = els[0].text_content() or ''
         return int(span_text.lower() == u'Ссылки на страницу содержат:'.lower())
 
-
     def get_region_code(self, default=None):
         dom = PyQuery(self.content)
         inputs = dom.find('input[name=rstr]')
@@ -735,6 +734,15 @@ class YandexParser(object):
             return int(inputs[0].attrib['value'].lstrip('-'))
         return default
 
+    def page_exists(self, page):
+        match = re.search(
+            '<(?:span|a) class="[^"]*pager__item[^"]*"[^>]*>\s*{}\s*</(?:span|a)>'.format(page),
+            self.content,
+            flags=re.I | re.M
+        )
+        return bool(match)
+
+
     def get_captcha_data(self):
         if 'checkcaptcha' not in self.content:
             return
